Radio Beam: Tools for Beam IO and Manipulation
==============================================

Radio Beam is a simple toolkit for reading beam information from FITS headers
and manipulating beams.  Some example applications include:

 * Convolution and deconvolution
 * Unit conversion (Jy to/from K)

[Basic Documentation](https://github.com/radio-astro-tools/radio_beam/blob/master/docs/index.rst) is available.

[![Build Status](https://travis-ci.org/radio-astro-tools/radio_beam.svg?branch=master)](https://travis-ci.org/radio-astro-tools/radio_beam)
